package com.bluebananagames.gametemplate.render;

import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.bluebananagames.gametemplate.game.Player;
import com.bluebananagames.gametemplate.input.Control;
import com.bluebananagames.gametemplate.screen.GameScreen;

public class WorldRenderer {

	private GameScreen gameScreen;
	private SpriteBatch batch;

	private Sprite backgroundSprite;
	private BitmapFont font;

	public WorldRenderer(GameScreen gameScreen, SpriteBatch batch) {
		this.gameScreen = gameScreen;
		this.batch = batch;

		initializeFonts();
		initializeSprites();
	}

	public void dispose() {
	}

	private void initializeSprites() {
		backgroundSprite = gameScreen.getAssets().getSprite("background.jpg");
	}

	private void initializeFonts() {
		font = gameScreen.getAssets().getFont("font32.fnt");
	}

	public void render(float delta) {
		batch.begin();
		renderBackground();
		renderText();
		batch.end();
	}

	private void renderText() {
		Player player = gameScreen.getPlayers().first();

		String text = "...";
		if (player.getInputHandler().isControlPressed(Control.UP)) {
			text = "UP";
		}
		if (player.getInputHandler().isControlPressed(Control.DOWN)) {
			text = "DOWN";
		}
		if (player.getInputHandler().isControlPressed(Control.LEFT)) {
			text = "LEFT";
		}
		if (player.getInputHandler().isControlPressed(Control.RIGHT)) {
			text = "RIGHT";
		}
		if (player.getInputHandler().isControlPressed(Control.FIRE)) {
			text = "FIRE";
		}

		font.draw(batch, text, 100, 500);
	}

	private void renderBackground() {
		backgroundSprite.draw(batch);
	}

	// HELPERS

}
